===============
django-refinery
===============

Django-refinery is a generic, reusable application to alleviate some of the more
mundane bits of view code.  Specifically allowing the users to filter down a
queryset based on a models fields, and displaying the form to let them do this.

Contents:

.. toctree::
    :maxdepth: 1
    
    install
    usage
    integration
    ref/filters
    ref/widgets
    tests
    history

